@@ -1,5 +1,5 @@
 # coding='utf-8'
-__version__ = '0.0.5'
+__version__ = '0.0.6'
 __usage__ = """
     USAGE:
         As a module from any location
@@ -15,7 +15,7 @@ __usage__ = """
         -mode           HTTPS or HTTP
 
 """
-# from outdated import check_outdated
-# is_outdated, latest = check_outdated("myhttps", __version__)
-# if is_outdated:
-#     print("The package lytools is out of date. Your version is %s, the latest is %s." % (__version__, latest))
\ No newline at end of file
+from outdated import check_outdated
+is_outdated, latest = check_outdated("myhttps", __version__)
+if is_outdated:
+    print("The package myhttps is out of date. Your version is %s, the latest is %s." % (__version__, latest))
\ No newline at end of file
