@@ -1,4 +1,4 @@
-# coding='utf-8'
+# coding=utf-8
 import os, sys, codecs
 from http.server import HTTPServer, SimpleHTTPRequestHandler
 from socketserver import ThreadingMixIn
@@ -30,7 +30,12 @@ class HTTP:
 class GenCert:
 
     def __init__(self):
-        self.mkdir('cert')
+        pwd = self.getcurrentPath()
+        self.certdir = os.path.join(pwd, 'cert')
+        self.KEY_FILE = os.path.join(self.certdir, 'key.pem')
+        self.CERT_FILE = os.path.join(self.certdir, 'cert.pem')
+        self.CERT_FILE = os.path.join(self.certdir, 'cert.pem')
+        self.mkdir(self.certdir)
         self.cert_gen()
         pass
 
@@ -44,9 +49,7 @@ class GenCert:
              organizationUnitName="organizationUnitName",
              serialNumber=0,
              validityStartInSeconds=0,
-             validityEndInSeconds=10 * 365 * 24 * 60 * 60,
-             KEY_FILE="cert/key.pem",
-             CERT_FILE="cert/cert.pem"):
+             validityEndInSeconds=10 * 365 * 24 * 60 * 60,):
 
         k = crypto.PKey()
         k.generate_key(crypto.TYPE_RSA, 2048)
@@ -65,9 +68,9 @@ class GenCert:
         cert.set_issuer(cert.get_subject())
         cert.set_pubkey(k)
         cert.sign(k, 'sha512')
-        with open(CERT_FILE, "wt") as f:
+        with open(self.CERT_FILE, "wt") as f:
             f.write(crypto.dump_certificate(crypto.FILETYPE_PEM, cert).decode("utf-8"))
-        with open(KEY_FILE, "wt") as f:
+        with open(self.KEY_FILE, "wt") as f:
             f.write(crypto.dump_privatekey(crypto.FILETYPE_PEM, k).decode("utf-8"))
     def mkdir(self, dir, force=False):
         if not os.path.isdir(dir):
@@ -76,6 +79,9 @@ class GenCert:
             else:
                 os.mkdir(dir)
 
+    def getcurrentPath(self):
+        return os.path.abspath(os.getcwd()) + '/'
+
 class Functions:
     def __init__(self):
         pass
@@ -111,8 +117,7 @@ class Functions:
 def main():
     host = '0.0.0.0'
     port = 11443
-    keyfile = 'cert/key.pem'
-    certfile = 'cert/cert.pem'
+
     mode='HTTPS'
     # print(os.path.exists(certfile));exit()
 
@@ -136,6 +141,8 @@ def main():
     if "-mode" in sys.argv:
         mode = sys.argv[sys.argv.index("-mode") + 1]
     if mode == 'HTTPS':
+        keyfile = GenCert().KEY_FILE
+        certfile = GenCert().CERT_FILE
         if not "-c" in sys.argv:
             if not os.path.exists(certfile):
                 GenCert()
